import Http from 'http';

import logger from './logger.js';
import { XfinityUsage } from './xfinity.js';

export interface UpdateHttp {
    (currentUsage: XfinityUsage): void;
}

export const createServer = (): UpdateHttp => {
    let usage: XfinityUsage | undefined;

    Http.createServer((req, res) => {
        const homeassistant = req.url === '/homeassistant';

        logger.debug(`HTTP request: ${req.url}`);

        if (req.url !== '/' && !homeassistant) {
            res.writeHead(404);
            res.end();
            return;
        }

        if (!usage) {
            res.writeHead(503);
            res.end();
            return;
        }

        res.writeHead(200, { 'Content-Type': 'application/json' });

        if (homeassistant) {
            const [current] = usage.usageMonths.slice(-1);
            const data = {
                total_usage: current.totalUsage,
                allowable_usage: current.allowableUsage,
                home_usage: current.homeUsage,
                wifi_usage: current.wifiUsage,
                courtesy_used: usage.courtesyUsed,
                courtesy_remaining: usage.courtesyRemaining,
                courtesy_allowed: usage.courtesyAllowed,
                in_paid_overage: usage.inPaidOverage,
                remaining_usage: current.allowableUsage - current.totalUsage,
            };
            res.write(JSON.stringify(data));
        } else {
            res.write(JSON.stringify(usage));
        }
        res.end();
    }).listen(7878);
    logger.info('http server started');

    const updateUsage = (currentUsage: XfinityUsage) => {
        usage = currentUsage;
    };

    return updateUsage;
};
